@@ -10,18 +10,24 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MARIADB_CLIENT_VERSION_STR	"10.5.6"
+#define MARIADB_CLIENT_VERSION_STR	"10.5.8"
 #define MARIADB_BASE_VERSION		"mariadb-10.5"
-#define MARIADB_VERSION_ID		100506
+#define MARIADB_VERSION_ID		100508
 #define MARIADB_PORT	        	3306
 #define MARIADB_UNIX_ADDR               "/run/mysqld/mysqld.sock"
+#ifndef MYSQL_UNIX_ADDR
+#define MYSQL_UNIX_ADDR MARIADB_UNIX_ADDR
+#endif
+#ifndef MYSQL_PORT
+#define MYSQL_PORT MARIADB_PORT
+#endif
 
 #define MYSQL_CONFIG_NAME               "my"
-#define MYSQL_VERSION_ID                100506
-#define MYSQL_SERVER_VERSION            "10.5.6-MariaDB"
+#define MYSQL_VERSION_ID                100508
+#define MYSQL_SERVER_VERSION            "10.5.8-MariaDB"
 
-#define MARIADB_PACKAGE_VERSION "3.1.9"
-#define MARIADB_PACKAGE_VERSION_ID 30109
+#define MARIADB_PACKAGE_VERSION "3.1.11"
+#define MARIADB_PACKAGE_VERSION_ID 30111
 #define MARIADB_SYSTEM_TYPE "Linux"
 #define MARIADB_MACHINE_TYPE "aarch64"
 #define MARIADB_PLUGINDIR "/usr/lib/mysql/plugin"
